==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/sr/templates.php <==
<?php
regGS("The template $1 is in use and can not be deleted.", "Шаблон $1 је у употреби и не може бити обрисан.");
regGS("The folder could not be deleted.", "Фолдер не може бити избрисан");
regGS("The directory must be empty", "Директоријум мора бити празан ");
regGS("Create new folder", "Направи нови фолдер");
regGS("Upload template", "Аплоудуј шаблон");
regGS("Creating new folder", "Прављење новог фолдера");
regGS("You do not have the right to create new folders.", "Немате право да правите нове фолдере");
regGS("The folder $1 could not be created", "Фолдер $1 не може бити направљен");
regGS("A file or folder having the name $1 already exists", "Фајл или фолдер са именом $1 већ постоји");
regGS("You do not have the right to delete templates.", "Немате право да бришете шаблоне");
regGS("Are you sure you want to delete the folder $1 from $2?", "Да ли сте сигурни да желите да обришете фолдер $1 из $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Да ли сте сигурни да желите да обришете шаблон $1 из фолдера $2?");
regGS("Deleting template", "Брисање шаблона");
regGS("Deleting folder", "Брисање фолдера");
regGS("Template $1 was deleted", "Шаблон $1 је обрисан");
regGS("Delete folder", "Обриши фолдер");
regGS("Folders", "Фолдери");
regGS("No folders.", "Нема фолдера");
regGS("Files", "Фајлови");
regGS("No templates.", "Нема шаблона");
regGS("Uploading template", "Аплоудовање шаблона");
regGS("File", "Фајл");
regGS("Create new template", "Креирај нови шаблон");
regGS("Creating new template", "Креирање новог шаблона");
regGS("Duplicate template", "Дуплирај шаблон");
regGS("Edit template", "Уреди шаблон");
regGS("The template $1 has been created.", "Шаблон $1 је креиран");
regGS("Do you want to edit the template ?", "Желите ли да уредите шаблон?");
regGS("The template $1 could not be created.", "Шаблон $1 не може бити креиран");
regGS("Template $1 was changed", "Шаблон $1 је промењен");
regGS("New template $1 was created", "Нови шаблон $1 је креиран");
regGS("Template $1 was duplicated into $2", "Шаблон $1 је дуплиран у $2");
regGS("Template charset", "Кодни распоред шаблона");
regGS("Select a language/character set", "Изабери језик/кодни распоред");
regGS("All languages", "Сви језици");
regGS("You do not have the right to modify templates.", "Немате право да мењате шаблоне.");
regGS("Invalid template file $1", "Погрешно име шаблона $1");
regGS("You do not have the right to create folders.", "Немате право да правите фолдере.");
regGS("You do not have the right to upload templates.", "Немате право да аплоудујете шаблоне.");
regGS("You do not have the right to create templates.", "Немате право да правите шаблоне.");
regGS("Duplicate file", "Дуплирај фајл");
regGS("Delete file", "Обриши фајл");
regGS("Unable to save the template '$1' to the path '$2'.", "Шаблон '$1'не може бити снимљен на путању '$2'.");
regGS("Please check if the user '$1' has permission to write in this directory.", "Проверите да ли корисник '$1'има овлашћења да уписује у овај директоријум.");
regGS("Unable to delete the template '$1' in the path '$2'.", "Шаблон '$1 'не може бити обрисан са путање '$2'.");
regGS("The folder has been deleted.", "Фолдер је избрисан");
regGS("The template has been deleted.", "Шаблон је избрисан");
regGS("The template could not be deleted.", "Шаблон не може бити избрисан");
regGS("Save", "Сними");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/sr/templates.php <==
<?php 
regGS("Template ID:", "");
regGS("Template ID", "");
regGS("Template $1 no longer exists!", "");
regGS("New template $1 created", "");
regGS("If the file you specified is a text file, you can convert its character set using the dropdown below.", "");
regGS("Directory $1 was deleted", "");
regGS("Directory $1 created.", "");
regGS("You must select a file to upload.", "");
regGS("You can only replace a file with a file of the same type.  The original file is of type \"$1\", and the file you uploaded was of type \"$2\".", "");
regGS("Unable to save the file '$1' to the path '$2'.", "");
regGS("Replace file:", "");
regGS("Replace", "");
regGS("File \"$1\" uploaded.", "");
regGS("File \"$1\" replaced.", "");
regGS("The folder name can't be '..' or '.'", "");
regGS("The template '$1' was saved successfully.", "Шаблон '$1' је успешно снимљен.");
regGS("The template $1 is in use and can not be deleted.", "Шаблон $1 је у употреби и не може бити обрисан.");
regGS("Create new folder", "Направи нови фолдер");
regGS("Upload template", "Аплоудуј шаблон");
regGS("You do not have the right to create new folders.", "Немате право да правите нове фолдере");
regGS("A file or folder having the name $1 already exists", "Фајл или фолдер са именом $1 већ постоји");
regGS("You do not have the right to delete templates.", "Немате право да бришете шаблоне");
regGS("Are you sure you want to delete the folder $1 from $2?", "Да ли сте сигурни да желите да обришете фолдер $1 из $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Да ли сте сигурни да желите да обришете шаблон $1 из фолдера $2?");
regGS("Template $1 was deleted", "Шаблон $1 је обрисан");
regGS("Delete folder", "Обриши фолдер");
regGS("Folders", "Фолдери");
regGS("No folders.", "Нема фолдера");
regGS("Files", "Фајлови");
regGS("No templates.", "Нема шаблона");
regGS("File", "Фајл");
regGS("Create new template", "Креирај нови шаблон");
regGS("Duplicate template", "Дуплирај шаблон");
regGS("Edit template", "Уреди шаблон");
regGS("The template $1 could not be created.", "Шаблон $1 не може бити креиран");
regGS("Template $1 was changed", "Шаблон $1 је промењен");
regGS("Template $1 was duplicated into $2", "Шаблон $1 је дуплиран у $2");
regGS("Template charset", "Кодни распоред шаблона");
regGS("Select a language/character set", "Изабери језик/кодни распоред");
regGS("All languages", "Сви језици");
regGS("You do not have the right to modify templates.", "Немате право да мењате шаблоне.");
regGS("Invalid template file $1", "Погрешно име шаблона $1");
regGS("You do not have the right to create folders.", "Немате право да правите фолдере.");
regGS("You do not have the right to upload templates.", "Немате право да аплоудујете шаблоне.");
regGS("You do not have the right to create templates.", "Немате право да правите шаблоне.");
regGS("Duplicate file", "Дуплирај фајл");
regGS("Delete file", "Обриши фајл");
regGS("Please check if the user '$1' has permission to write in this directory.", "Проверите да ли корисник '$1'има овлашћења да уписује у овај директоријум.");
regGS("The folder has been deleted.", "Фолдер је избрисан");
regGS("The template has been deleted.", "Шаблон је избрисан");
regGS("The template could not be deleted.", "Шаблон не може бити избрисан");
regGS("Save", "Сними");
?>
